@@ -1,11 +1,6 @@
 import os
 
-from mozprocess import ProcessHandler
-from mozprofile import FirefoxProfile, Preferences
-from mozprofile.permissions import ServerLocations
-from mozrunner import FirefoxRunner
-
-from .base import get_free_port, NullBrowser, ExecutorBrowser, require_arg
+from .base import NullBrowser, ExecutorBrowser, require_arg
 from ..executors import get_executor_kwargs
 from ..executors.executorservo import ServoTestharnessExecutor
 
@@ -19,16 +14,20 @@ __wptrunner__ = {"product": "servo",
                  "executor_kwargs": "get_executor_kwargs",
                  "env_options": "env_options"}
 
+
 def check_args(**kwargs):
     require_arg(kwargs, "binary")
 
+
 def browser_kwargs(**kwargs):
     return {"binary": kwargs["binary"]}
 
+
 def env_options():
     return {"host": "localhost",
             "bind_hostname": "true"}
 
+
 class ServoBrowser(NullBrowser):
     def __init__(self, logger, binary):
         NullBrowser.__init__(self, logger)
