@@ -4,7 +4,6 @@
 
 from __future__ import unicode_literals
 
-import hashlib
 import json
 import logging
 import os
@@ -13,21 +12,14 @@ import socket
 import sys
 import threading
 import time
-import traceback
-import urlparse
 from StringIO import StringIO
 from collections import defaultdict, OrderedDict
 from multiprocessing import Queue
 
-import moznetwork
-from mozlog.structured import structuredlog, commandline, stdadapter
-from mozlog.structured.formatters import JSONFormatter
-from mozlog.structured.handlers import StreamHandler
-from mozprocess import ProcessHandler
+from mozlog.structured import commandline, stdadapter
 
 import manifestexpected
 import manifestinclude
-import metadata
 import products
 import wptcommandline
 import wpttest
@@ -63,7 +55,6 @@ logger = None
 
 def setup_logging(args, defaults):
     global logger
-    setup_compat_args(args)
     logger = commandline.setup_logging("web-platform-tests", args, defaults)
     setup_stdlib_logger()
 
@@ -84,7 +75,8 @@ def do_test_relative_imports(test_root):
 
     sys.path.insert(0, os.path.join(test_root))
     sys.path.insert(0, os.path.join(test_root, "tools", "scripts"))
-    import serve, manifest
+    import serve
+    import manifest
 
 
 class TestEnvironmentError(Exception):
@@ -100,6 +92,7 @@ class TestEnvironment(object):
         self.config = None
         self.test_server_port = options.pop("test_server_port", True)
         self.options = options if options is not None else {}
+        self.required_files = options.pop("required_files", [])
         self.files_to_restore = []
 
     def __enter__(self):
@@ -129,13 +122,11 @@ class TestEnvironment(object):
             data = f.read()
             local_config = json.loads(data % self.options)
 
-        rv = serve.merge_json(default_config, local_config)
-        return rv
+        return serve.merge_json(default_config, local_config)
 
     def copy_required_files(self):
         logger.info("Placing required files in server environment.")
-        for source, destination, copy_if_exists in [("testharness_runner.html", "", False),
-                                                    ("testharnessreport.js", "resources/", True)]:
+        for source, destination, copy_if_exists in self.required_files:
             source_path = os.path.join(here, source)
             dest_path = os.path.join(self.test_path, destination, os.path.split(source)[1])
             if os.path.exists(dest_path):
@@ -155,7 +146,8 @@ class TestEnvironment(object):
                     try:
                         s.connect((self.config["host"], port))
                     except socket.error:
-                        raise EnvironmentError("%s server on port %d failed to start" % (scheme, port))
+                        raise EnvironmentError(
+                            "%s server on port %d failed to start" % (scheme, port))
                     finally:
                         s.close()
 
@@ -168,6 +160,7 @@ class TestEnvironment(object):
             if os.path.exists(path + ".orig"):
                 os.rename(path + ".orig", path)
 
+
 class TestChunker(object):
     def __init__(self, total_chunks, chunk_number):
         self.total_chunks = total_chunks
@@ -177,6 +170,7 @@ class TestChunker(object):
     def __call__(self, manifest):
         raise NotImplementedError
 
+
 class Unchunked(TestChunker):
     def __init__(self, *args, **kwargs):
         TestChunker.__init__(self, *args, **kwargs)
@@ -186,6 +180,7 @@ class Unchunked(TestChunker):
         for item in manifest:
             yield item
 
+
 class HashChunker(TestChunker):
     def __call__(self):
         chunk_index = self.chunk_number - 1
@@ -193,11 +188,12 @@ class HashChunker(TestChunker):
             if hash(test_path) % self.total_chunks == chunk_index:
                 yield test_path, tests
 
+
 class EqualTimeChunker(TestChunker):
     """Chunker that uses the test timeout as a proxy for the running time of the test"""
 
     def _get_chunk(self, manifest_items):
-        # For each directory containing tests, calculate the mzximum execution time after running all
+        # For each directory containing tests, calculate the maximum execution time after running all
         # the tests in that directory. Then work out the index into the manifest corresponding to the
         # directories at fractions of m/N of the running time where m=1..N-1 and N is the total number
         # of chunks. Return an array of these indicies
@@ -217,21 +213,25 @@ class EqualTimeChunker(TestChunker):
                 by_dir[test_dir] = PathData()
 
             data = by_dir[test_dir]
-            time = sum(test.timeout for test in tests)
+            time = sum(wpttest.DEFAULT_TIMEOUT if test.timeout !=
+                       "long" else wpttest.LONG_TIMEOUT for test in tests)
             data.time += time
             data.tests.append((test_path, tests))
 
             total_time += time
 
+        full_total_time = total_time
+
         if len(by_dir) < self.total_chunks:
-            raise ValueError("Tried to split into %i chunks, but only %i subdirectories included" % (self.total_chunks, len(by_dir)))
+            raise ValueError("Tried to split into %i chunks, but only %i subdirectories included" % (
+                self.total_chunks, len(by_dir)))
 
         n_chunks = self.total_chunks
         time_per_chunk = float(total_time) / n_chunks
 
         chunks = []
 
-        # Put any individual dirs with a time greater than the timeout into their own
+        # Put any individual dirs with a time greater than the time_per_chunk into their own
         # chunk
         while True:
             to_remove = []
@@ -240,7 +240,7 @@ class EqualTimeChunker(TestChunker):
                     to_remove.append((path, data))
             if to_remove:
                 for path, data in to_remove:
-                    chunks.append(([path], data.tests))
+                    chunks.append([[path], data.tests, data.time])
                     del by_dir[path]
 
                 n_chunks -= len(to_remove)
@@ -249,42 +249,45 @@ class EqualTimeChunker(TestChunker):
             else:
                 break
 
-        chunk_time = 0
+        start_new = True
         for i, (path, data) in enumerate(by_dir.iteritems()):
-            if i == 0:
+            if start_new:
                 # Always start a new chunk the first time
-                chunks.append(([path], data.tests))
-                chunk_time = data.time
-            elif chunk_time + data.time > time_per_chunk:
-                if (abs(time_per_chunk - chunk_time) <=
-                    abs(time_per_chunk - (chunk_time + data.time))):
+                chunks.append([[path], data.tests, data.time])
+                start_new = False
+            elif chunks[-1][2] + data.time > time_per_chunk:
+                if ((abs(time_per_chunk - chunks[-1][2]) <=
+                     abs(time_per_chunk - (chunks[-1][2] + data.time))) and
+                    i < n_chunks - 1):
                     # Add a new chunk
-                    chunks.append(([path], data.tests))
-                    chunk_time = data.time
+                    chunks.append([[path], data.tests, data.time])
                 else:
                     # Add this to the end of the previous chunk but
                     # start a new chunk next time
                     chunks[-1][0].append(path)
                     chunks[-1][1].extend(data.tests)
-                    chunk_time += data.time
+                    chunks[-1][2] += data.time
+                    start_new = True
             else:
                 # Append this to the previous chunk
                 chunks[-1][0].append(path)
                 chunks[-1][1].extend(data.tests)
-                chunk_time += data.time
+                chunks[-1][2] += data.time
 
         assert len(chunks) == self.total_chunks, len(chunks)
+        assert sum(item[2] for item in chunks) == full_total_time
+
         chunks = sorted(chunks)
 
         return chunks[self.chunk_number - 1][1]
 
-
     def __call__(self, manifest_iter):
         manifest = list(manifest_iter)
         tests = self._get_chunk(manifest)
         for item in tests:
             yield item
 
+
 class TestFilter(object):
     def __init__(self, include=None, exclude=None, manifest_path=None):
         if manifest_path is not None and include is None:
@@ -311,6 +314,7 @@ class TestFilter(object):
             if include_tests:
                 yield test_path, include_tests
 
+
 class TestLoader(object):
     def __init__(self, tests_root, metadata_root, test_filter, run_info):
         self.tests_root = tests_root
@@ -346,6 +350,9 @@ class TestLoader(object):
     def iter_tests(self, test_types, chunker=None):
         manifest_items = self.test_filter(self.manifest.itertypes(*test_types))
 
+        if chunker is not None:
+            manifest_items = chunker(manifest_items)
+
         for test_path, tests in manifest_items:
             expected_file = self.load_expected_manifest(test_path)
             for manifest_test in tests:
@@ -366,8 +373,6 @@ class TestLoader(object):
         """Read in the tests from the manifest file and add them to a queue"""
         rv = defaultdict(list)
 
-        manifest_items = self.test_filter(self.manifest.itertypes(*test_types))
-
         chunker = {"none": Unchunked,
                    "hash": HashChunker,
                    "equal_time": EqualTimeChunker}[chunk_type](total_chunks,
@@ -406,6 +411,7 @@ class TestLoader(object):
 
         return test_ids, tests_queue
 
+
 class LogThread(threading.Thread):
     def __init__(self, queue, logger, level):
         self.queue = queue
@@ -419,6 +425,8 @@ class LogThread(threading.Thread):
                 msg = self.queue.get()
             except EOFError:
                 break
+            except IOError:
+                break
             if msg is None:
                 break
             else:
@@ -428,6 +436,7 @@ class LogThread(threading.Thread):
 class LoggingWrapper(StringIO):
     """Wrapper for file like objects to redirect output to logger
     instead"""
+
     def __init__(self, queue, prefix=None):
         self.queue = queue
         self.prefix = prefix
@@ -449,6 +458,7 @@ class LoggingWrapper(StringIO):
     def flush(self):
         pass
 
+
 def list_test_groups(tests_root, metadata_root, test_types, product, **kwargs):
     do_test_relative_imports(tests_root)
 
@@ -460,6 +470,7 @@ def list_test_groups(tests_root, metadata_root, test_types, product, **kwargs):
     for item in sorted(test_loader.get_groups(test_types)):
         print item
 
+
 def list_disabled(tests_root, metadata_root, test_types, product, **kwargs):
     rv = []
     run_info = wpttest.get_run_info(product, debug=False)
@@ -470,6 +481,7 @@ def list_disabled(tests_root, metadata_root, test_types, product, **kwargs):
             rv.append({"test": test.id, "reason": test.disabled()})
     print json.dumps(rv, indent=2)
 
+
 def run_tests(tests_root, metadata_root, product, **kwargs):
     logging_queue = None
     logging_thread = None
@@ -537,7 +549,8 @@ def run_tests(tests_root, metadata_root, product, **kwargs):
                                                           **kwargs)
 
                     if executor_cls is None:
-                        logger.error("Unsupported test type %s for product %s" % (test_type, product))
+                        logger.error("Unsupported test type %s for product %s" %
+                                     (test_type, product))
                         continue
 
                     with ManagerGroup("web-platform-tests",
@@ -577,35 +590,18 @@ def run_tests(tests_root, metadata_root, product, **kwargs):
     return manager_group.unexpected_count() == 0
 
 
-def setup_compat_args(kwargs):
-    if not "log_raw" in kwargs or kwargs["log_raw"] is None:
-        kwargs["log_raw"] = []
-
-    if "output_file" in kwargs:
-        path = kwargs.pop("output_file")
-        if path is not None:
-            output_dir = os.path.split(path)[0]
-            if not os.path.exists(output_dir):
-                os.makedirs(output_dir)
-            kwargs["log_raw"].append(open(path, "w"))
-
-    if "log_stdout" in kwargs:
-        if kwargs.pop("log_stdout"):
-            kwargs["log_raw"].append(sys.stdout)
-
 def main():
     """Main entry point when calling from the command line"""
-    args = wptcommandline.parse_args()
-    kwargs = vars(args)
+    kwargs = wptcommandline.parse_args()
 
     if kwargs["prefs_root"] is None:
         kwargs["prefs_root"] = os.path.abspath(os.path.join(here, "prefs"))
 
     setup_logging(kwargs, {"raw": sys.stdout})
 
-    if args.list_test_groups:
+    if kwargs["list_test_groups"]:
         list_test_groups(**kwargs)
-    elif args.list_disabled:
+    elif kwargs["list_disabled"]:
         list_disabled(**kwargs)
     else:
         return run_tests(**kwargs)
